==> gchempaint-0.5.1.tar.gz: gchempaint-0.5.1/lib/view.h <==
// -*- C++ -*-

/* 
 * GChemPaint library
 * view.h 
 *
 * Copyright (C) 2001-2004
 *
 * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef GCHEMPAINT_VIEW_H
#define GCHEMPAINT_VIEW_H

#include <map>
#include <list>
#include <libgnomeprint/gnome-print.h>
#include <libgnomecanvas/libgnomecanvas.h>
#include <libgcpcanvas/gcp-canvas-rich-text.h>
#include "atom.h"
#include "bond.h"

class gcpDocument;
class gcpWidgetData;

#define GCHEMPAINT_ATOM_NAME "application/gchempaint"
extern GtkTargetEntry const targets[];

class gcpView
{
public:
	//Constructor and destructor
	gcpView(gcpDocument *pDoc, bool Embedded);
	virtual ~gcpView();

	//Interface	
public:
	GtkWidget* GetWidget() {return m_pWidget;}
	gcpDocument* GetDoc() {return m_pDoc;}
	bool OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget);
	void AddObject(Object* pObject);
	void Update(Object* pObject);
	GtkWidget* CreateNewWidget();
	void OnDestroy(GtkWidget* widget);
	GnomeCanvasItem* GetCanvasItem(GtkWidget* widget, Object* Object);
	void Print(GnomePrintContext *pc, gdouble width, gdouble height);
	GnomeCanvasItem* GetBackground();
	double GetZoomFactor();
	void UpdateFont();
	void Remove(Object* pObject);
	PangoContext* GetPangoContext() {return m_PangoContext;}
	double GetFontHeight() {return m_dFontHeight;}
	gchar* GetFontName() {return m_sFontName;}
	gchar* GetSmallFontName() {return m_sSmallFontName;}
	gchar* GetTinyFontName() {return m_sTinyFontName;}
	PangoFontDescription* GetPangoFontDesc() {return m_PangoFontDesc;}
	PangoFontDescription* GetPangoSmallFontDesc() {return m_PangoSmallFontDesc;}
	PangoFontDescription* GetPangoTinyFontDesc() {return m_PangoTinyFontDesc;}
	void UpdateLabel(const gchar* label);
	void OnDeleteSelection(GtkWidget* w);
	void OnCopySelection(GtkWidget* w, GtkClipboard* clipboard);
	void OnPasteSelection(GtkWidget* w, GtkClipboard* clipboard);
	void OnCutSelection(GtkWidget* w, GtkClipboard* clipboard);
	bool OnKeyPress(GtkWidget* w, GdkEventKey* event);
	bool OnKeyRelease(GtkWidget* w, GdkEventKey* event);
	bool OnSize(int width, int height);
	void UpdateSize(double x1, double y1, double x2, double y2);
	void SetGnomeCanvasRichTextActive(GnomeCanvasRichTextExt* item);
	bool PrepareUnselect();
	void OnReceive(GtkClipboard* clipboard, GtkSelectionData* selection_data);
	void OnSelectAll();
	bool IsEmbedded() {return m_bEmbedded;}
	int GetNbWidgets () {return m_Widgets.size ();}

	//Implementation
private:
	gcpWidgetData* m_pData;
	gcpDocument* m_pDoc;
	GtkWidget* m_pWidget;
	std::list<GtkWidget*>m_Widgets;
	PangoContext* m_PangoContext;
	PangoFontDescription* m_PangoFontDesc, *m_PangoSmallFontDesc, *m_PangoTinyFontDesc;
	double m_dFontHeight;
	gchar* m_sFontName, *m_sSmallFontName, *m_sTinyFontName;
	double m_DefaultPadding;
	double m_DefaultBondWidth;
	double m_DefaultBondLength;
	double m_DefaultBondDist;
	double m_DefaultArrowLength;
	double m_DefaultArrowHeadA;
	double m_DefaultArrowHeadB;
	double m_DefaultArrowHeadC;
	double m_DefaultArrowDist;
	double m_DefaultStereoBondWidth;
	double m_DefaultHashWidth;
	double m_DefaultHashDist;
	double m_DefaultArrowPadding;
	double m_DefaultSignPadding;
	int m_width, m_height;
	double m_lastx, m_lasty;
	GnomeCanvasRichTextExt* m_ActiveRichText;
	bool m_bEmbedded;
};

bool on_event(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget);
void on_receive(GtkClipboard *clipboard, GtkSelectionData *selection_data, gcpView * pView);
#endif // GCHEMPAINT_VIEW_H

==> gchempaint-0.5.4.tar.gz: gchempaint-0.5.4/lib/view.h <==
// -*- C++ -*-

/* 
 * GChemPaint library
 * view.h 
 *
 * Copyright (C) 2001-2004
 *
 * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef GCHEMPAINT_VIEW_H
#define GCHEMPAINT_VIEW_H

#include <map>
#include <list>
#include <libgnomeprint/gnome-print.h>
#include <libgnomecanvas/libgnomecanvas.h>
#include <libgcpcanvas/gcp-canvas-rich-text.h>
#include "atom.h"
#include "bond.h"

class gcpDocument;
class gcpWidgetData;

#define GCHEMPAINT_ATOM_NAME "application/gchempaint"
extern GtkTargetEntry const targets[];

class gcpView
{
public:
	//Constructor and destructor
	gcpView(gcpDocument *pDoc, bool Embedded);
	virtual ~gcpView();

	//Interface	
public:
	GtkWidget* GetWidget() {return m_pWidget;}
	gcpDocument* GetDoc() {return m_pDoc;}
	bool OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget);
	void AddObject(Object* pObject);
	void Update(Object* pObject);
	GtkWidget* CreateNewWidget();
	void OnDestroy(GtkWidget* widget);
	GnomeCanvasItem* GetCanvasItem(GtkWidget* widget, Object* Object);
	void Print(GnomePrintContext *pc, gdouble width, gdouble height);
	GnomeCanvasItem* GetBackground();
	double GetZoomFactor();
	void UpdateFont();
	void Remove(Object* pObject);
	PangoContext* GetPangoContext() {return m_PangoContext;}
	double GetFontHeight() {return m_dFontHeight;}
	gchar* GetFontName() {return m_sFontName;}
	gchar* GetSmallFontName() {return m_sSmallFontName;}
	gchar* GetTinyFontName() {return m_sTinyFontName;}
	PangoFontDescription* GetPangoFontDesc() {return m_PangoFontDesc;}
	PangoFontDescription* GetPangoSmallFontDesc() {return m_PangoSmallFontDesc;}
	PangoFontDescription* GetPangoTinyFontDesc() {return m_PangoTinyFontDesc;}
	void UpdateLabel(const gchar* label);
	void OnDeleteSelection(GtkWidget* w);
	void OnCopySelection(GtkWidget* w, GtkClipboard* clipboard);
	void OnPasteSelection(GtkWidget* w, GtkClipboard* clipboard);
	void OnCutSelection(GtkWidget* w, GtkClipboard* clipboard);
	bool OnKeyPress(GtkWidget* w, GdkEventKey* event);
	bool OnKeyRelease(GtkWidget* w, GdkEventKey* event);
	bool OnSize(int width, int height);
	void UpdateSize(double x1, double y1, double x2, double y2);
	void SetGnomeCanvasRichTextActive(GnomeCanvasRichTextExt* item);
	bool PrepareUnselect();
	void OnReceive(GtkClipboard* clipboard, GtkSelectionData* selection_data);
	void OnSelectAll();
	bool IsEmbedded() {return m_bEmbedded;}
	int GetNbWidgets () {return m_Widgets.size ();}
	void ExportImage (const char* filename, const char* type);
	double GetArrowPadding () {return m_ArrowPadding;}
	double GetStoechiometryPadding () {return m_StoechiometryPadding;}
	double GetBaseLineOffset () {return m_BaseLineOffset;}

	//Implementation
private:
	gcpWidgetData* m_pData;
	gcpDocument* m_pDoc;
	GtkWidget* m_pWidget;
	std::list<GtkWidget*>m_Widgets;
	PangoContext* m_PangoContext;
	PangoFontDescription* m_PangoFontDesc, *m_PangoSmallFontDesc, *m_PangoTinyFontDesc;
	double m_dFontHeight;
	gchar* m_sFontName, *m_sSmallFontName, *m_sTinyFontName;
	double m_DefaultPadding;
	double m_DefaultBondWidth;
	double m_DefaultBondLength;
	double m_DefaultBondDist;
	double m_DefaultArrowLength;
	double m_DefaultArrowHeadA;
	double m_DefaultArrowHeadB;
	double m_DefaultArrowHeadC;
	double m_DefaultArrowDist;
	double m_DefaultStereoBondWidth;
	double m_DefaultHashWidth;
	double m_DefaultHashDist;
	double m_DefaultObjectPadding;
	double m_DefaultSignPadding;
	double m_ArrowPadding;
	double m_StoechiometryPadding;
	double m_BaseLineOffset;
	int m_width, m_height;
	double m_lastx, m_lasty;
	GnomeCanvasRichTextExt* m_ActiveRichText;
	bool m_bEmbedded;
	GtkUIManager *m_UIManager;
	bool m_Dragging;
};

bool on_event(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget);
void on_receive(GtkClipboard *clipboard, GtkSelectionData *selection_data, gcpView * pView);
#endif // GCHEMPAINT_VIEW_H
